@@ -100,7 +100,7 @@ def _get_host_obj(data: Dict[str, Any]) -> Host:
 class FlatDataInventory:
     def __init__(
             self,
-            data: List [Dict]
+            data: List[Dict]
     ) -> None:
         self.hosts_list = data
 
@@ -115,7 +115,6 @@ class FlatDataInventory:
         return Inventory(hosts=hosts, groups=groups, defaults=defaults)
 
 
-
 class CSVInventory(FlatDataInventory):
     def __init__(
             self,
@@ -135,12 +134,10 @@ class ExcelInventory(FlatDataInventory):
     ) -> None:
         self.hosts_list = []
         dataframe = pd.read_excel(excel_file)
+        dataframe.fillna('')
         items = dataframe.to_dict(orient='records')
         super().__init__(data=items)
 
 
-
 if __name__ == '__main__':
-    t = ExcelInventory()
-    inv = t.load()
-    print(inv)
+    ...
